@@ -862,13 +862,13 @@ class SBtabTable():
         '''
         try:
             import pandas as pd
-            rows = self._get_rows()
+            rows = self.value_rows
             n_cols = max(map(len, rows))
             if rba: column_names = list(map(lambda s: s, self.columns))
             else: column_names = list(map(lambda s: s[1:], self.columns))
             while len(column_names) < n_cols:
                 column_names += ['Col%d' % len(column_names)]
-            df = pd.DataFrame(data=self._get_rows(), columns=column_names)
+            df = pd.DataFrame(data=self.value_rows, columns=column_names)
             return df
         except:
             raise SBtabError('Pandas dataframe could not be built.')
